==> open-xchange-core_7.8.4.orig.tar.bz2: open-xchange-core-7.8.4/com.openexchange.guest.impl/src/com/openexchange/guest/impl/internal/GlobalDBConnectionHelper.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guest.impl.internal;

import com.openexchange.database.DatabaseService;
import com.openexchange.database.Databases;
import com.openexchange.exception.OXException;
import com.openexchange.server.ServiceLookup;

/**
 *
 * Used to handle connections to the global database transactionally.
 *
 * @author <a href="mailto:martin.schneider@open-xchange.com">Martin Schneider</a>
 * @since 7.8.0
 */
public class GlobalDBConnectionHelper extends AbstractConnectionHelper {

    private final int contextId;
    private final String groupId;

    public GlobalDBConnectionHelper(ServiceLookup services, boolean needsWritable, int contextId) {
        super(services, needsWritable);
        this.contextId = contextId;
        this.groupId = null;
    }

    public GlobalDBConnectionHelper(ServiceLookup services, boolean needsWritable, String groupId) {
        super(services, needsWritable);
        this.contextId = -1;
        this.groupId = groupId;
    }

    /**
     * Backs the underlying connection in case the connection is owned by this instance, rolling back automatically if not yet committed.
     *
     * @throws OXException
     */
    @Override
    public void finish() {
        if (false == committed) {
            Databases.rollback(connection);
        }
        Databases.autocommit(connection);
        if (writableConnection) {
            if (contextId != -1) {
                services.getService(DatabaseService.class).backWritableForGlobal(contextId, connection);
            } else {
                services.getService(DatabaseService.class).backWritableForGlobal(groupId, connection);
            }
        } else {
            if (contextId != -1) {
                services.getService(DatabaseService.class).backReadOnlyForGlobal(contextId, connection);
            } else {
                services.getService(DatabaseService.class).backReadOnlyForGlobal(groupId, connection);
            }
        }
    }

    @Override
    public void acquireConnection() throws OXException {
        DatabaseService dbService = services.getService(DatabaseService.class);
        if (contextId != -1) {
            this.connection = this.writableConnection ? dbService.getWritableForGlobal(contextId) : dbService.getReadOnlyForGlobal(contextId);
        } else {
            this.connection = this.writableConnection ? dbService.getWritableForGlobal(groupId) : dbService.getReadOnlyForGlobal(groupId);
        }
    }
}

==> open-xchange-core_7.10.4.orig.tar.bz2: open-xchange-core-7.10.4/com.openexchange.guest.impl/src/com/openexchange/guest/impl/internal/GlobalDBConnectionHelper.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guest.impl.internal;

import com.openexchange.database.DatabaseService;
import com.openexchange.database.Databases;
import com.openexchange.exception.OXException;
import com.openexchange.server.ServiceLookup;

/**
 *
 * Used to handle connections to the global database transactionally.
 *
 * @author <a href="mailto:martin.schneider@open-xchange.com">Martin Schneider</a>
 * @since 7.8.0
 */
public class GlobalDBConnectionHelper extends AbstractConnectionHelper {

    private final int contextId;
    private final String groupId;

    /**
     * Initializes a new {@link GlobalDBConnectionHelper}.
     * 
     * @param services The service lookup
     * @param needsWritable <code>true</code> if connections used by this helper needs to be writable, <code>false</code> for read only
     * @param contextId The context identifier
     */
    public GlobalDBConnectionHelper(ServiceLookup services, boolean needsWritable, int contextId) {
        super(services, needsWritable);
        this.contextId = contextId;
        this.groupId = null;
    }

    /**
     * Initializes a new {@link GlobalDBConnectionHelper}.
     * 
     * @param services The service lookup
     * @param needsWritable <code>true</code> if connections used by this helper needs to be writable, <code>false</code> for read only
     * @param groupId The group identifier
     */
    public GlobalDBConnectionHelper(ServiceLookup services, boolean needsWritable, String groupId) {
        super(services, needsWritable);
        this.contextId = -1;
        this.groupId = groupId;
    }

    /**
     * Backs the underlying connection in case the connection is owned by this instance, rolling back automatically if not yet committed.
     */
    @Override
    public void finish() {
        if (false == committed) {
            Databases.rollback(connection);
        }
        Databases.autocommit(connection);
        if (writableConnection) {
            if (contextId != -1) {
                services.getService(DatabaseService.class).backWritableForGlobal(contextId, connection);
            } else {
                services.getService(DatabaseService.class).backWritableForGlobal(groupId, connection);
            }
        } else {
            if (contextId != -1) {
                services.getService(DatabaseService.class).backReadOnlyForGlobal(contextId, connection);
            } else {
                services.getService(DatabaseService.class).backReadOnlyForGlobal(groupId, connection);
            }
        }
    }

    @Override
    public void acquireConnection() throws OXException {
        DatabaseService dbService = services.getService(DatabaseService.class);
        if (contextId != -1) {
            this.connection = this.writableConnection ? dbService.getWritableForGlobal(contextId) : dbService.getReadOnlyForGlobal(contextId);
        } else {
            this.connection = this.writableConnection ? dbService.getWritableForGlobal(groupId) : dbService.getReadOnlyForGlobal(groupId);
        }
    }
}
